@@ -122,6 +122,7 @@ class CreateDevice:
             self.ptz_absoluteEx_url = '%s/ISAPI/PTZCtrl/channels/1/absoluteEx' % self._base
             self.onepushfocus_url = '%s/ISAPI/PTZCtrl/channels/1/onepushfoucs/start' % self._base
             self.absoluteStatus_url = '%s/ISAPI/PTZCtrl/channels/1/status' % self._base
+            self.imageFocus_url = '%s/ISAPI/Image/channels/1/focusConfiguration' % self._base
 
         else:
             self.motion_url = '%s/MotionDetection/1' % self._base
@@ -168,18 +169,18 @@ class CreateDevice:
     def set_ptzabsoluteEx(self,elevation,azimuth,absoluteZoom ,focus,focalLen,horizontalSpeed=10.00,verticalSpeed=10.00,zoomType='focalLen',element_to_query=None):
         data_xml = '<?xml version="1.0" encoding="UTF-8"?>' +\
                     '<PTZAbsoluteEx version="2.0" xmlns="http://www.isapi.org/ver20/XMLSchema">' +\
-                    '<elevation>'+ elevation +'</elevation>'+\
-                    '<azimuth>'+ azimuth +'</azimuth>'+\
-                    '<absoluteZoom>'+ absoluteZoom +'</absoluteZoom>'+\
-                    '<focus>'+ focus +'</focus>'+\
-                    '<focalLen>'+ focalLen +'</focalLen>'+\
-                    '<horizontalSpeed>'+ horizontalSpeed +'</horizontalSpeed>'+\
-                    '<verticalSpeed>'+ verticalSpeed +'</verticalSpeed>'+\
-                    '<zoomType>'+ zoomType +'</zoomType>'+\
+                    '<elevation>'+ str(elevation) +'</elevation>'+\
+                    '<azimuth>'+ str(azimuth) +'</azimuth>'+\
+                    '<absoluteZoom>'+ str(absoluteZoom) +'</absoluteZoom>'+\
+                    '<focus>'+ str(focus) +'</focus>'+\
+                    '<focalLen>'+ str(focalLen) +'</focalLen>'+\
+                    '<horizontalSpeed>'+ str(horizontalSpeed) +'</horizontalSpeed>'+\
+                    '<verticalSpeed>'+ str(verticalSpeed) +'</verticalSpeed>'+\
+                    '<zoomType>'+ str(zoomType) +'</zoomType>'+\
                     '</PTZAbsoluteEx>'
         # 转换为UTF-8编码
         data_xml = data_xml.encode('utf-8')
-        print(data_xml)
+        # print(data_xml)
         response = requests.put(
             self.ptz_absoluteEx_url,
             auth=self._auth_fn(self._username, self._password),
@@ -192,8 +193,8 @@ class CreateDevice:
             return None
 
         if element_to_query is None:
-            print(response.status_code)
-            print(response.text)
+            # print(response.status_code)
+            # print(response.text)
             return response.text
         try:
             tree = tree_no_ns_from_string(response.text)
@@ -384,6 +385,7 @@ class CreateDevice:
             data=data_xml,
             )
         if response.status_code != 200:
+            print(response)
             return response.text
 
         if element_to_query is None:
@@ -411,7 +413,7 @@ class CreateDevice:
             '<focalLen>1</focalLen>'+\
             '<horizontalSpeed>0.00</horizontalSpeed>'+\
             '<verticalSpeed>0.00</verticalSpeed>'+\
-            '<zoomType>absoluteZoom</zoomType>'+\
+            '<zoomType>%s</zoomType>'+\
         '</PTZAbsoluteEx>'
         response = requests.get(
             self.ptz_senior_url,
@@ -436,8 +438,39 @@ class CreateDevice:
         except AttributeError as attib_err:
             return None
         return None
+    
+    # 设置图像参数,聚焦模式,聚焦限制 focusStyle: SEMIAUTOMATIC 半自动, MANUAL 手动, AUTO 自动，focusLimited: 聚焦限制 int, [10#10厘米,50#50厘米,100#1米,150#1.5米,300#3米,600#6米,1000#10米,2000#20米,5000#50米,20000#200米,50000#500米,65535#655.35米] 
+    def set_image_capabilities(self,focusStyle='SEMIAUTOMATIC',focusLimited=10, element_to_query=None):
+        data_xml = '<?xml version: "1.0" encoding="UTF-8"?>' +\
+        '<FocusConfiguration>' +\
+        '<focusStyle>'+ str(focusStyle) +'</focusStyle>' +\
+        '<focusLimited>'+ str(focusLimited) +'</focusLimited>'+\
+        '</FocusConfiguration>' 
         
-           
+        response = requests.put(
+            self.imageFocus_url,
+            auth=self._auth_fn(self._username, self._password),
+            data=data_xml,
+            )
+        if response.status_code != 200:
+            print(response)
+            return response.text
+
+        if element_to_query is None:
+            return response.text
+        try:
+            tree = tree_no_ns_from_string(response.text)
+
+            element_to_query = './/%s%s' % (
+                self._xml_namespace, element_to_query)
+            result = tree.findall(element_to_query)
+            if len(result) > 0:
+                return result[0].text.strip()
+
+        except AttributeError as attib_err:
+            return None
+        return None
+    
     def set_ptz(self, element_to_query=None, up_down=0, left_right=0, zoom=0):
         pan =left_right * 15
         tilt = -up_down * 15
