@@ -2278,3 +2278,44 @@ class get_track_record_response(msg):
     def __init__(self):
         super().__init__()
         self.msg = self.msg_class()
+        
+# 日志上传
+class task_update_log(msg):
+    """
+    定义一个应用消息,消息结构如下：
+    {
+        "data":{
+            "task_type":"",
+            "content":"",
+            "task_id":"",
+            "rec_num":"",
+            "rec_type":"",
+            "rec_in":"",
+            "rec_out":"",
+            "iType":"",
+            "camera_id":"",
+            "sType":"",
+            "sImgname":""
+        }
+    }
+    """
+    topic = "/task/update_log"
+    
+    class data_class(NestedClass):
+        def __init__(self):
+            super().__init__()
+            self.task_type = ''
+            self.content = ''
+            self.task_id = ''
+            self.rec_num = ''
+            self.rec_type = ''
+            self.rec_in = ''
+            self.rec_out = ''
+            self.iType = ''
+            self.camera_id = ''
+            self.sType = ''
+            self.sImgname = ''
+            
+    def __init__(self):
+        super().__init__()
+        self.data = self.data_class()
